@@ -1,7 +1,7 @@
 #include "properties_dialog.h"
 
 #include "data_base_management.h"
-#include "library_creator.h"
+#include "initial_comic_info_extractor.h"
 #include "yacreader_field_edit.h"
 #include "yacreader_field_plain_text_edit.h"
 #include "db_helper.h"
@@ -9,7 +9,6 @@
 
 #include <QHBoxLayout>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QSizePolicy>
 #include <QFormLayout>
 #include <QCheckBox>
@@ -22,8 +21,10 @@
 #include <QPushButton>
 #include <QMessageBox>
 
+using namespace YACReader;
+
 PropertiesDialog::PropertiesDialog(QWidget *parent)
-    : QDialog(parent)
+    : QDialog(parent), updated(false)
 {
 
     createCoverBox();
@@ -36,11 +37,11 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     createTabBar();
 
     mainLayout = new QGridLayout;
-    //mainLayout->addWidget(coverBox,0,0);
+    // mainLayout->addWidget(coverBox,0,0);
     mainLayout->addWidget(tabBar, 0, 1);
     mainLayout->setColumnStretch(1, 1);
     /*mainLayout->addWidget(authorsBox,1,1);
-	mainLayout->addWidget(publishingBox,2,1);*/
+        mainLayout->addWidget(publishingBox,2,1);*/
     mainLayout->addWidget(buttonBox, 1, 1, Qt::AlignBottom);
 
     mainWidget = new QWidget(this);
@@ -49,12 +50,17 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     mainWidget->setLayout(mainLayout);
     mainLayout->setSizeConstraint(QLayout::SetMinimumSize);
 
-    int heightDesktopResolution = QApplication::desktop()->screenGeometry().height();
-    int widthDesktopResolution = QApplication::desktop()->screenGeometry().width();
+    QScreen *screen = parent != nullptr ? parent->window()->screen() : nullptr;
+    if (screen == nullptr) {
+        screen = QApplication::screens().constFirst();
+    }
+
+    int heightDesktopResolution = screen->geometry().height();
+    int widthDesktopResolution = screen->geometry().width();
     int sHeight, sWidth;
     sHeight = static_cast<int>(heightDesktopResolution * 0.65);
     sWidth = static_cast<int>(sHeight * 1.4);
-    //setCover(QPixmap(":/images/notCover.png"));
+    // setCover(QPixmap(":/images/notCover.png"));
 
     this->move(QPoint((widthDesktopResolution - sWidth) / 2, ((heightDesktopResolution - sHeight) - 40) / 2));
     setModal(true);
@@ -63,7 +69,7 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     mainWidget->move(280, 0);
 }
 
-QSize PropertiesDialog::sizeHint()
+QSize PropertiesDialog::sizeHint() const
 {
     return QSize(750, 444);
 }
@@ -116,19 +122,19 @@ void PropertiesDialog::createCoverBox()
     coverBox->move(0, 444 - 28);
     layout->setContentsMargins(5, 4, 5, 0);
 
-    //busyIndicator = new YACReaderBusyWidget(this);
-    //busyIndicator->move((280-busyIndicator->width())/2,(444-busyIndicator->height()-28)/2);
-    //busyIndicator->hide();
+    // busyIndicator = new YACReaderBusyWidget(this);
+    // busyIndicator->move((280-busyIndicator->width())/2,(444-busyIndicator->height()-28)/2);
+    // busyIndicator->hide();
 
-    connect(showPreviousCoverPageButton, SIGNAL(clicked()), this, SLOT(loadPreviousCover()));
-    connect(showNextCoverPageButton, SIGNAL(clicked()), this, SLOT(loadNextCover()));
+    connect(showPreviousCoverPageButton, &QAbstractButton::clicked, this, &PropertiesDialog::loadPreviousCover);
+    connect(showNextCoverPageButton, &QAbstractButton::clicked, this, &PropertiesDialog::loadNextCover);
 }
 
 QFrame *createLine()
 {
     QFrame *line = new QFrame();
     line->setObjectName(QString::fromUtf8("line"));
-    //line->setGeometry(QRect(320, 150, 118, 3));
+    // line->setGeometry(QRect(320, 150, 118, 3));
     line->setFrameShape(QFrame::HLine);
     line->setFrameShadow(QFrame::Sunken);
 
@@ -142,7 +148,7 @@ void PropertiesDialog::createGeneralInfoBox()
     auto generalInfoLayout = new QFormLayout;
 
     generalInfoLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
-    //generalInfoLayout->setRowWrapPolicy(QFormLayout::WrapAllRows);
+    // generalInfoLayout->setRowWrapPolicy(QFormLayout::WrapAllRows);
     generalInfoLayout->addRow(tr("Title:"), title = new YACReaderFieldEdit());
 
     auto number = new QHBoxLayout;
@@ -157,7 +163,7 @@ void PropertiesDialog::createGeneralInfoBox()
     countEdit->setValidator(&countValidator);
     number->addStretch(1);
     /*generalInfoLayout->addRow(tr("&Issue number:"), );
-	generalInfoLayout->addRow(tr("&Bis:"), );*/
+        generalInfoLayout->addRow(tr("&Bis:"), );*/
     generalInfoLayout->addRow(tr("Issue number:"), number);
 
     generalInfoLayout->addRow(tr("Volume:"), volumeEdit = new YACReaderFieldEdit());
@@ -179,8 +185,8 @@ void PropertiesDialog::createGeneralInfoBox()
 
     generalInfoLayout->addRow(tr("Size:"), size = new QLabel("size"));
 
-    //generalInfoLayout->addRow(tr("Comic Vine link:"), comicVineLink = new QLabel("..."));
-    //generalInfoLayout->addRow(bottom);
+    // generalInfoLayout->addRow(tr("Comic Vine link:"), comicVineLink = new QLabel("..."));
+    // generalInfoLayout->addRow(bottom);
 
     auto main = new QVBoxLayout;
     main->addLayout(generalInfoLayout);
@@ -197,7 +203,7 @@ void PropertiesDialog::createAuthorsBox()
 
     auto authorsLayout = new QVBoxLayout;
 
-    //authorsLayout->setRowWrapPolicy(QFormLayout::WrapAllRows);
+    // authorsLayout->setRowWrapPolicy(QFormLayout::WrapAllRows);
     auto h1 = new QHBoxLayout;
     auto vl1 = new QVBoxLayout;
     auto vr1 = new QVBoxLayout;
@@ -207,8 +213,8 @@ void PropertiesDialog::createAuthorsBox()
     vr1->addWidget(new QLabel(tr("Penciller(s):")));
     vr1->addWidget(penciller = new YACReaderFieldPlainTextEdit());
     h1->addLayout(vr1);
-    //authorsLayout->addRow(tr("Writer(s):"), new YACReaderFieldPlainTextEdit());
-    //authorsLayout->addRow(tr("Penciller(s):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Writer(s):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Penciller(s):"), new YACReaderFieldPlainTextEdit());
     auto h2 = new QHBoxLayout;
     auto vl2 = new QVBoxLayout;
     auto vr2 = new QVBoxLayout;
@@ -219,8 +225,8 @@ void PropertiesDialog::createAuthorsBox()
     vr2->addWidget(colorist = new YACReaderFieldPlainTextEdit());
     h2->addLayout(vr2);
 
-    //authorsLayout->addRow(tr("Inker(s):"), new YACReaderFieldPlainTextEdit());
-    //authorsLayout->addRow(tr("Colorist(s):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Inker(s):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Colorist(s):"), new YACReaderFieldPlainTextEdit());
 
     auto h3 = new QHBoxLayout;
     auto vl3 = new QVBoxLayout;
@@ -231,8 +237,8 @@ void PropertiesDialog::createAuthorsBox()
     vr3->addWidget(new QLabel(tr("Cover Artist(s):")));
     vr3->addWidget(coverArtist = new YACReaderFieldPlainTextEdit());
     h3->addLayout(vr3);
-    //authorsLayout->addRow(tr("Letterer(es):"), new YACReaderFieldPlainTextEdit());
-    //authorsLayout->addRow(tr("Cover Artist(s):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Letterer(es):"), new YACReaderFieldPlainTextEdit());
+    // authorsLayout->addRow(tr("Cover Artist(s):"), new YACReaderFieldPlainTextEdit());
 
     authorsLayout->addLayout(h1);
     authorsLayout->addLayout(h2);
@@ -296,11 +302,13 @@ void PropertiesDialog::createButtonBox()
 
     closeButton = buttonBox->addButton(QDialogButtonBox::Close);
     saveButton = buttonBox->addButton(QDialogButtonBox::Save);
-    //rotateWidgetsButton = buttonBox->addButton(tr("Rotate &Widgets"),QDialogButtonBox::ActionRole);
+    previousButton = buttonBox->addButton("<", QDialogButtonBox::ButtonRole::NoRole);
+    nextButton = buttonBox->addButton(">", QDialogButtonBox::ButtonRole::NoRole);
 
-    //connect(rotateWidgetsButton, SIGNAL(clicked()), this, SLOT(rotateWidgets()));
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
-    connect(saveButton, SIGNAL(clicked()), this, SLOT(save()));
+    connect(closeButton, &QAbstractButton::clicked, this, &PropertiesDialog::close);
+    connect(saveButton, &QAbstractButton::clicked, this, &PropertiesDialog::saveAndClose);
+    connect(previousButton, &QAbstractButton::clicked, this, &PropertiesDialog::saveAndOpenPrevious);
+    connect(nextButton, &QAbstractButton::clicked, this, &PropertiesDialog::saveAndOpenNext);
 }
 
 QImage blurred(const QImage &image, const QRect &rect, int radius, bool alphaOnly = false)
@@ -371,12 +379,8 @@ QImage blurred(const QImage &image, const QRect &rect, int radius, bool alphaOnl
     return result;
 }
 
-void PropertiesDialog::setComics(QList<ComicDB> comics)
+void PropertiesDialog::loadComic(ComicDB &comic)
 {
-    this->comics = comics;
-
-    ComicDB comic = comics.at(0);
-
     if (!comic.info.title.isNull())
         title->setText(comic.info.title.toString());
     if (!comic.info.comicVineID.isNull()) {
@@ -385,7 +389,7 @@ void PropertiesDialog::setComics(QList<ComicDB> comics)
     } else
         comicVineLink->setHidden(true);
 
-    if (comics.length() == 1 && !comic.info.coverPage.isNull()) {
+    if (!comic.info.coverPage.isNull()) {
         coverPageEdit->setText(comic.info.coverPage.toString());
         coverPageValidator.setRange(1, comic.info.numPages.toInt());
         coverPageEdit->setValidator(&coverPageValidator);
@@ -405,14 +409,14 @@ void PropertiesDialog::setComics(QList<ComicDB> comics)
         coverChanged = false;
         coverBox->show();
 
-        if (!QFileInfo(basePath + comics[0].path).exists()) {
+        if (!QFileInfo(basePath + comic.path).exists()) {
             QMessageBox::warning(this, tr("Not found"), tr("Comic not found. You should update your library."));
             showPreviousCoverPageButton->setDisabled(true);
             showNextCoverPageButton->setDisabled(true);
         }
     }
     /*if(comic.info.numPages != NULL)
-	numPagesEdit->setText(QString::number(*comic.info.numPages));*/
+        numPagesEdit->setText(QString::number(*comic.info.numPages));*/
 
     if (!comic.info.number.isNull())
         numberEdit->setText(comic.info.number.toString());
@@ -479,6 +483,36 @@ void PropertiesDialog::setComics(QList<ComicDB> comics)
     if (!comic.info.notes.isNull())
         notes->setPlainText(comic.info.notes.toString());
 
+    this->setWindowTitle(tr("Edit comic information"));
+    setCover(comic.info.getCover(basePath));
+}
+
+void PropertiesDialog::updateButtons()
+{
+    if (sequentialEditing) {
+        previousButton->setDisabled(currentComicIndex == 0);
+        nextButton->setDisabled(currentComicIndex == comics.length() - 1);
+        previousButton->setHidden(false);
+        nextButton->setHidden(false);
+    } else {
+        previousButton->setHidden(true);
+        nextButton->setHidden(true);
+    }
+}
+
+void PropertiesDialog::setComics(QList<ComicDB> comics)
+{
+    updated = false;
+    sequentialEditing = false;
+
+    this->comics = comics;
+
+    ComicDB comic = comics[0];
+
+    loadComic(comic);
+
+    updateButtons();
+
     if (comics.length() > 1) {
         coverBox->hide();
 
@@ -549,12 +583,22 @@ void PropertiesDialog::setComics(QList<ComicDB> comics)
             if (itr->info.notes.isNull() || itr->info.notes.toString() != notes->toPlainText())
                 notes->clear();
         }
-    } else {
-        this->setWindowTitle(tr("Edit comic information"));
-        setCover(comic.info.getCover(basePath));
     }
 }
 
+void PropertiesDialog::setComicsForSequentialEditing(int currentComicIndex, QList<ComicDB> comics)
+{
+    updated = false;
+    sequentialEditing = true;
+
+    this->comics = comics;
+    this->currentComicIndex = currentComicIndex;
+
+    loadComic(comics[currentComicIndex]);
+
+    updateButtons();
+}
+
 void PropertiesDialog::updateComics()
 {
     QString connectionName = "";
@@ -563,9 +607,13 @@ void PropertiesDialog::updateComics()
         db.open();
         db.transaction();
         QList<ComicDB>::iterator itr;
-        for (itr = comics.begin(); itr != comics.end(); itr++) {
-            if (itr->info.edited)
+        QList<ComicDB>::iterator begin = sequentialEditing ? comics.begin() + currentComicIndex : comics.begin();
+        QList<ComicDB>::iterator end = sequentialEditing ? comics.begin() + currentComicIndex + 1 : comics.end();
+        for (itr = begin; itr != end; itr++) {
+            if (itr->info.edited) {
                 DBHelper::update(&(itr->info), db);
+                updated = true;
+            }
         }
         db.commit();
         connectionName = db.connectionName();
@@ -604,24 +652,26 @@ void PropertiesDialog::setSize(float sizeFloat)
 void PropertiesDialog::save()
 {
     QList<ComicDB>::iterator itr;
-    for (itr = comics.begin(); itr != comics.end(); itr++) {
-        //Comic & comic = comics[0];
+    QList<ComicDB>::iterator begin = sequentialEditing ? comics.begin() + currentComicIndex : comics.begin();
+    QList<ComicDB>::iterator end = sequentialEditing ? comics.begin() + currentComicIndex + 1 : comics.end();
+    for (itr = begin; itr != end; itr++) {
         bool edited = false;
 
         if (title->isModified()) {
-            itr->info.title = title->text();
+            auto titleString = title->text();
+            itr->info.title = titleString.isEmpty() ? QVariant() : title->text();
             edited = true;
         }
 
-        if (comics.size() == 1)
+        if (sequentialEditing)
             if (coverChanged) {
-                itr->info.coverPage = coverPageNumberLabel->text();
+                itr->info.coverPage = coverPageNumberLabel->text().toInt();
                 edited = true;
             }
 
         /*if(comic.info.numPages != NULL)
-		numPagesEdit->setText(QString::number(*comic.info.numPages));*/
-        if (comics.size() == 1)
+                numPagesEdit->setText(QString::number(*comic.info.numPages));*/
+        if (sequentialEditing)
             if (numberEdit->isModified()) {
                 if (numberEdit->text().isEmpty())
                     itr->info.number = QVariant();
@@ -629,7 +679,7 @@ void PropertiesDialog::save()
                     itr->info.number = numberEdit->text();
                 edited = true;
             }
-        if (comics.size() == 1)
+        if (sequentialEditing)
             if (!itr->info.isBis.isNull() || isBisCheck->isChecked()) {
                 itr->info.isBis = isBisCheck->isChecked();
                 edited = true;
@@ -648,7 +698,7 @@ void PropertiesDialog::save()
             itr->info.storyArc = storyArcEdit->text();
             edited = true;
         }
-        if (comics.size() == 1)
+        if (sequentialEditing)
             if (arcNumberEdit->isModified() && !arcNumberEdit->text().isEmpty()) {
                 itr->info.arcNumber = arcNumberEdit->text();
                 edited = true;
@@ -731,23 +781,61 @@ void PropertiesDialog::save()
         itr->info.edited = edited;
     }
 
-    if (comics.count() == 1) {
-        if (coverChanged) // && coverPageEdit->text().toInt() != *comics[0].info.coverPage)
-        {
-            ThumbnailCreator tc(basePath + comics[0].path, basePath + "/.yacreaderlibrary/covers/" + comics[0].info.hash + ".jpg", comics[0].info.coverPage.toInt());
-            tc.create();
+    if (sequentialEditing) {
+        if (coverChanged) {
+            InitialComicInfoExtractor ie(basePath + comics[currentComicIndex].path, basePath + "/.yacreaderlibrary/covers/" + comics[currentComicIndex].info.hash + ".jpg", comics[currentComicIndex].info.coverPage.toInt());
+            ie.extract();
 
-            if (tc.getOriginalCoverSize().second > 0) {
-                comics[0].info.originalCoverSize = QString("%1x%2").arg(tc.getOriginalCoverSize().first).arg(tc.getOriginalCoverSize().second);
-                comics[0].info.coverSizeRatio = static_cast<float>(tc.getOriginalCoverSize().first) / tc.getOriginalCoverSize().second;
+            if (ie.getOriginalCoverSize().second > 0) {
+                comics[currentComicIndex].info.originalCoverSize = QString("%1x%2").arg(ie.getOriginalCoverSize().first).arg(ie.getOriginalCoverSize().second);
+                comics[currentComicIndex].info.coverSizeRatio = static_cast<float>(ie.getOriginalCoverSize().first) / ie.getOriginalCoverSize().second;
             }
         }
     }
+}
+
+void PropertiesDialog::saveAndOpenPrevious()
+{
+    save();
+
+    updateComics();
+
+    coverChanged = false;
+
+    currentComicIndex--;
+
+    loadComic(comics[currentComicIndex]);
+
+    updateButtons();
+
+    repaint();
+}
+
+void PropertiesDialog::saveAndOpenNext()
+{
+    save();
+
+    updateComics();
+
+    coverChanged = false;
+
+    currentComicIndex++;
+
+    loadComic(comics[currentComicIndex]);
+
+    updateButtons();
+
+    repaint();
+}
+
+void PropertiesDialog::saveAndClose()
+{
+    save();
 
     updateComics();
 
     close();
-    emit(accepted());
+    emit accepted();
 }
 
 void PropertiesDialog::setDisableUniqueValues(bool disabled)
@@ -812,10 +900,10 @@ void PropertiesDialog::paintEvent(QPaintEvent *event)
 
     p.drawPixmap(0, 0, coverImage);
 
-    //QPixmap shadow(":/images/social_dialog/shadow.png");
-    //p.drawPixmap(280-shadow.width(),0,shadow.width(),444,shadow);
+    // QPixmap shadow(":/images/social_dialog/shadow.png");
+    // p.drawPixmap(280-shadow.width(),0,shadow.width(),444,shadow);
     p.drawLine(279, 0, 279, 444);
-    if (comics.length() == 1)
+    if (sequentialEditing)
         p.fillRect(0, 444 - 28, 280, 28, QColor(0, 0, 0, 153));
 }
 
@@ -828,21 +916,21 @@ void PropertiesDialog::updateCoverPageNumberLabel(int n)
 void PropertiesDialog::loadNextCover()
 {
     int current = coverPageNumberLabel->text().toInt();
-    if (current < comics.at(0).info.numPages.toInt()) {
+    if (current < comics[currentComicIndex].info.numPages.toInt()) {
         updateCoverPageNumberLabel(current + 1);
 
-        ThumbnailCreator tc(basePath + comics[0].path, "", current + 1);
-        tc.create();
-        setCover(tc.getCover());
+        InitialComicInfoExtractor ie(basePath + comics[currentComicIndex].path, "", current + 1);
+        ie.extract();
+        setCover(ie.getCover());
         repaint();
 
-        if ((current + 1) == comics.at(0).info.numPages.toInt()) {
+        if ((current + 1) == comics[currentComicIndex].info.numPages.toInt()) {
             showNextCoverPageButton->setDisabled(true);
         }
 
         showPreviousCoverPageButton->setEnabled(true);
-        //busyIndicator->show();
-        if (current + 1 != comics.at(0).info.coverPage)
+        // busyIndicator->show();
+        if (current + 1 != comics[currentComicIndex].info.coverPage)
             coverChanged = true;
         else
             coverChanged = false;
@@ -854,9 +942,9 @@ void PropertiesDialog::loadPreviousCover()
     int current = coverPageNumberLabel->text().toInt();
     if (current != 1) {
         updateCoverPageNumberLabel(current - 1);
-        ThumbnailCreator tc(basePath + comics[0].path, "", current - 1);
-        tc.create();
-        setCover(tc.getCover());
+        InitialComicInfoExtractor ie(basePath + comics[currentComicIndex].path, "", current - 1);
+        ie.extract();
+        setCover(ie.getCover());
         repaint();
 
         if ((current - 1) == 1) {
@@ -864,10 +952,19 @@ void PropertiesDialog::loadPreviousCover()
         }
 
         showNextCoverPageButton->setEnabled(true);
-        //busyIndicator->show();
-        if (current - 1 != comics.at(0).info.coverPage.toInt())
+        // busyIndicator->show();
+        if (current - 1 != comics[currentComicIndex].info.coverPage.toInt())
             coverChanged = true;
         else
             coverChanged = false;
     }
 }
+
+bool PropertiesDialog::close()
+{
+    if (updated) {
+        emit accepted();
+    }
+
+    return QDialog::close();
+}
